@@ -28,12 +28,12 @@
 #include "libwpd_internal.h"
 #include <limits>
 
-_WPXContentParsingState::_WPXContentParsingState() :
+WPXContentParsingState::WPXContentParsingState() :
 	m_textAttributeBits(0),
 	m_fontSize(12.0/*WP6_DEFAULT_FONT_SIZE*/), // FIXME ME!!!!!!!!!!!!!!!!!!! HELP WP6_DEFAULT_FONT_SIZE
 	m_fontName(new librevenge::RVNGString(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman")), // EN PAS DEFAULT FONT AAN VOOR WP5/6/etc
 	m_fontColor(new RGBSColor(0x00,0x00,0x00,0x64)), //Set default to black. Maybe once it will change, but for the while...
-	m_highlightColor(0),
+	m_highlightColor(),
 
 	m_isParagraphColumnBreak(false),
 	m_isParagraphPageBreak(false),
@@ -119,11 +119,8 @@ _WPXContentParsingState::_WPXContentParsingState() :
 {
 }
 
-_WPXContentParsingState::~_WPXContentParsingState()
+WPXContentParsingState::~WPXContentParsingState()
 {
-	DELETEP(m_fontName);
-	DELETEP(m_fontColor);
-	DELETEP(m_highlightColor);
 }
 
 WPXContentListener::WPXContentListener(std::list<WPXPageSpan> &pageList, librevenge::RVNGTextInterface *documentInterface) :
@@ -136,7 +133,6 @@ WPXContentListener::WPXContentListener(std::list<WPXPageSpan> &pageList, libreve
 
 WPXContentListener::~WPXContentListener()
 {
-	DELETEP(m_ps);
 }
 
 void WPXContentListener::startDocument()
@@ -378,12 +374,12 @@ void WPXContentListener::_openPageSpan()
 	bool pageNumberInserted = false;
 
 	std::vector<WPXHeaderFooter> headerFooterList = currentPage.getHeaderFooterList();
-	for (std::vector<WPXHeaderFooter>::iterator iter = headerFooterList.begin(); iter != headerFooterList.end(); ++iter)
+	for (const auto &hf : headerFooterList)
 	{
-		if (((*iter).getOccurrence() != NEVER) && !currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
+		if ((hf.getOccurrence() != NEVER) && !currentPage.getHeaderFooterSuppression(hf.getInternalType()))
 		{
 			propList.clear();
-			switch ((*iter).getOccurrence())
+			switch (hf.getOccurrence())
 			{
 			case ODD:
 				propList.insert("librevenge:occurrence", "odd");
@@ -399,7 +395,7 @@ void WPXContentListener::_openPageSpan()
 				break;
 			}
 
-			if ((*iter).getType() == HEADER)
+			if (hf.getType() == HEADER)
 			{
 				m_documentInterface->openHeader(propList);
 				if (!currentPage.getPageNumberSuppression() &&
@@ -416,9 +412,9 @@ void WPXContentListener::_openPageSpan()
 				m_documentInterface->openFooter(propList);
 
 			WPD_DEBUG_MSG(("Header Footer Element: Starting to parse the subDocument\n"));
-			handleSubDocument((*iter).getSubDocument(), WPX_SUBDOCUMENT_HEADER_FOOTER, (*iter).getTableList(), 0);
+			handleSubDocument(hf.getSubDocument(), WPX_SUBDOCUMENT_HEADER_FOOTER, hf.getTableList(), 0);
 			WPD_DEBUG_MSG(("Header Footer Element: End of the subDocument parsing\n"));
-			if ((*iter).getType() == HEADER)
+			if (hf.getType() == HEADER)
 				m_documentInterface->closeHeader();
 			else
 			{
@@ -434,7 +430,7 @@ void WPXContentListener::_openPageSpan()
 			}
 
 			WPD_DEBUG_MSG(("Header Footer Element: type: %i occurrence: %i\n",
-			               (*iter).getType(), (*iter).getOccurrence()));
+			               hf.getType(), hf.getOccurrence()));
 		}
 	}
 
@@ -890,9 +886,9 @@ void WPXContentListener::_openSpan()
 	if (attributeBits & WPX_REDLINE_BIT)
 		propList.insert("fo:color", "#ff3333");  // #ff3333 = a nice bright red
 	else if (m_ps->m_fontColor)
-		propList.insert("fo:color", _colorToString(m_ps->m_fontColor));
+		propList.insert("fo:color", _colorToString(m_ps->m_fontColor.get()));
 	if (m_ps->m_highlightColor)
-		propList.insert("fo:background-color", _colorToString(m_ps->m_highlightColor));
+		propList.insert("fo:background-color", _colorToString(m_ps->m_highlightColor.get()));
 
 	if (!m_ps->m_isSpanOpened)
 		m_documentInterface->openSpan(propList);
@@ -1048,7 +1044,7 @@ void WPXContentListener::_closeTableRow()
 				// m_ps->m_currentTableCol++;
 				// Fill the table row untill the end with empty cells
 				RGBSColor tmpCellBorderColor(0x00, 0x00, 0x00, 0x64);
-				_openTableCell(1, 1, 0xFF, 0, 0, &tmpCellBorderColor, TOP);
+				_openTableCell(1, 1, 0xFF, nullptr, nullptr, &tmpCellBorderColor, TOP);
 				_closeTableCell();
 			}
 			else
@@ -1200,8 +1196,8 @@ void WPXContentListener::handleSubDocument(const WPXSubDocument *subDocument, WP
                                            WPXTableList tableList, unsigned nextTableIndice)
 {
 	// save our old parsing state on our "stack"
-	WPXContentParsingState *oldPS = m_ps;
-	m_ps = new WPXContentParsingState();
+	auto oldPS = std::move(m_ps);
+	m_ps = std::unique_ptr<WPXContentParsingState>(new WPXContentParsingState());
 	// BEGIN: copy page properties into the new parsing state
 	m_ps->m_pageFormWidth = oldPS->m_pageFormWidth;
 	m_ps->m_pageMarginLeft = oldPS->m_pageMarginLeft;
@@ -1240,8 +1236,7 @@ void WPXContentListener::handleSubDocument(const WPXSubDocument *subDocument, WP
 	setUndoOn(oldIsUndoOn);
 	if (m_ps->m_subDocumentType == WPX_SUBDOCUMENT_TEXT_BOX)
 		_closeSection();
-	delete m_ps;
-	m_ps = oldPS;
+	m_ps = std::move(oldPS);
 }
 
 void WPXContentListener::insertBreak(const unsigned char breakType)
